import 'package:flutter_test/flutter_test.dart';
import 'package:intl/intl.dart';
import 'package:wakatime_api/apis/wakatime_api.dart';
import 'package:wakatime_api/models/project_heartbeat_duration.dart';
import 'package:wakatime_api/models/simple_heartbeat_duration.dart';

void main() {
  group('Tests for heartbeat fetching', () {
    final apis = WakatimeApi('<YOUR-API-TOKEN>');
    test('Get 08-02-2022 heartbeats', () async {
      final date = DateTime(2022, 02, 08);
      final heartbeats = await apis.getHeartbeats(date);
      expect(heartbeats, isNotEmpty);
    });

    test('Get 01-02-2022 >-> 08-02-20222 heartbeats', () async {
      final heartbeats = await apis.getHeartBeatsForRange(
        DateTime(2022, 02, 01),
        DateTime(2022, 02, 08),
      );
      expect(
        heartbeats,
        isNotEmpty,
        reason: 'Heartbeats should not be empty',
      );
      final formatter = DateFormat('yyyy-MM-dd');
      expect(
        formatter.format(DateTime.parse(heartbeats.first.createdAt)),
        '2022-02-01',
      );
      expect(
        formatter.format(DateTime.parse(heartbeats.last.createdAt)),
        '2022-02-08',
      );
    });

    test('Get projects', () async {
      final projects = await apis.getProjects();
      expect(projects, isNotEmpty);
    });

    test('Get user durations', () async {
      final allDurations = await apis.getDurations();
      final projectDuration = await apis.getDurations(project: 'wakatime_api');
      expect(allDurations.length, lessThan(projectDuration.length));

      expect(allDurations.first is SimpleHeartbeatDuration, true);
      expect(projectDuration.first is ProjectHeartbeatDuration, true);
    });

    test('Get all data', () async {
      final allData = await apis.getAllTimeSinceToday();
      expect(allData, isNotNull);
    });
  });
}
